from .menus import Menus
from .menus.menu import Menu


class Dropdown(dict):
    @property
    def title(self): ...
    @title.setter
    def title(self, value): ...

    @property
    def menus(self)-> Menus | list[Menu]: ...
    def is_menu(self)-> bool: ...
    def is_dropdown(self)-> bool: ...
