from ..comment import Comment
from ..script import Script
from ..text import Text
from ... import Htmdoc
from ...__tags_creater__ import TagsCreater
from ...node import Node


class Wrap(Node, TagsCreater):
    def __init__(self, u: Htmdoc | Wrap, content=None): ...
    @property
    def juniors(self)-> dict[int, Node]: ...

    def comment(self, content: str = None)-> Comment: ...
    def script(self, content: str = None)-> Script: ...
    def text(self, content: str = None)-> Text: ...
    def wrap(self, content=None, associated:Node=None)-> Wrap: ...

    def append(self, element=None)-> Node | list[Node] | None: ...

    def ___anchor_to___(self, node: Node): ...
    @property
    def anchored(self)-> Node | None: ...
    def is_anchored(self)-> bool: ...
