from io import BytesIO

from ...types.he import He
from ..file_folder import FileFolder


class File(FileFolder):
    def __init__(self, u: He, path: str): ...

    @property
    def base_name(self)-> str: ...
    @property
    def extension_name(self)-> str: ...
    def is_exists(self)-> bool: ...
    def is_unexists(self)-> bool: ...
    def parse_json(self)-> list | dict | None: ...
    def read_content(self)-> str: ...
    def read_lines(self)-> list[str]: ...
    def read_bytes(self)-> bytes: ...
    def save_content(self, content: str)-> None: ...
    def save_json(self, data: dict)-> None: ...
    def copy_to(self, path: File | str)-> bool: ...
    def copy_from(self, path: File | str)-> bool: ...
    def save_io(self, io: BytesIO)-> bool: ...
