
from .core import Image
from .core import (IconClose, IconDemo, IconDocument, IconHelp, IconHome, IconIcon, IconInfo, IconLangauge,
                   IconMaximize, IconMinimize, IconMore, IconNormalize, IconQuite, IconSetting, IconUser, IconHebill,
                   IconYangs)
