from ..website.webmod import Webmod
from ....types.he import He


class Webapp(He):
    def __init__(self, webmod: Webmod): ...

    @property
    def x(self)-> Webmod: ...

    def page_iterative(self): ...
    def page_content(self): ...

    def page_layout(self): ...

    def page_block_navbar(self): ...
    def page_block_breadcrumb(self): ...
    def page_block_navigations(self): ...
    def page_block_messages(self): ...
    def page_block_footer(self): ...
    def page_block_debugs(self): ...

    def page_block_1010(self): ...
    def page_block_1020(self): ...
    def page_block_1030(self): ...
    def page_block_1040(self): ...
    def page_block_1050(self): ...
    def page_block_1060(self): ...
    def page_block_1070(self): ...
    def page_block_1080(self): ...
    def page_block_1090(self): ...
    def page_block_1100(self): ...
