from .builtins import HeEro
from ..system.types.he import He



def _dict(self:He, dict_attr_name, es:HeEro): ...
def _key(func, args, kwargs, dict_item_key, dict_item_key_by_arg, dict_item_key_by_func, func_name_striped, es:HeEro): ...

def parse_dict_item_value(dict_attr_name: str = None, dict_item_key: str = None, dict_item_key_by_arg: str | int = None, func_name_striped: bool = None): ...
def parse_self_item_value(dict_item_key: str | int = None, dict_item_key_by_arg: str | int = None, func_name_striped: bool = None): ...
def parse_self_x_item_value(dict_item_key: str | int = None, dict_item_key_by_arg: str | int = None, func_name_striped: bool = None): ...
def parse_self_d_item_value(dict_item_key: str | int = None, dict_item_key_by_arg: str | int = None, func_name_striped: bool = None): ...
def parse_dict_item_value_or_set_by_func(dict_attr_name: str = None, dict_item_key: str = None, dict_item_key_by_arg: str | int = None, func_name_striped: bool = None, execute_if_none: bool = None): ...
def parse_self_item_value_or_set_by_func(dict_item_key: str = None, dict_item_key_by_arg: str | int = None, func_name_striped: bool = None, execute_if_none: bool = None): ...
def parse_self_x_item_value_or_set_by_func(dict_item_key: str = None, dict_item_key_by_arg: str | int = None, func_name_striped: bool = None, execute_if_none: bool = None): ...
def parse_self_d_item_value_or_set_by_func(dict_item_key: str = None, dict_item_key_by_arg: str | int = None, func_name_striped: bool = None, execute_if_none: bool = None): ...

def _module_name(func, module_name, module_name_striped:bool|None): ...
def _instance(self:He, func, args, kwargs, module_name, arg0, module_name_striped: bool|None, search_from_self: bool|None, es:HeEro): ...
def instance_he_by_module_name(module_name: str = None, arg0: str = None, module_name_striped: bool = None, search_from_self: bool = None): ...
def parse_dict_item_value_or_set_by_instance_he_by_module_name(dict_attr_name: str = None, dict_item_key: str = None, dict_item_key_by_arg: str | int = None, dict_item_key_by_func: bool = None, func_name_striped: bool = None, execute_if_none: bool = None, module_name: str = None, arg0: str = None, module_name_striped: bool = None, search_from_self: bool = None): ...
def parse_self_item_value_or_set_by_instance_he_by_module_name(dict_item_key: str = None, dict_item_key_by_arg: str | int = None, dict_item_key_by_func: bool = None, func_name_striped: bool = None, execute_if_none: bool = None, module_name: str = None, arg0: str = None, module_name_striped: bool = None, search_from_self: bool = None): ...
def parse_self_x_item_value_or_set_by_instance_he_by_module_name(dict_item_key: str = None, dict_item_key_by_arg: str | int = None, dict_item_key_by_func: bool = None, func_name_striped: bool = None, execute_if_none: bool = None, module_name: str = None, arg0: str = None, module_name_striped: bool = None, search_from_self: bool = None): ...
def parse_self_d_item_value_or_set_by_instance_he_by_module_name(dict_item_key: str = None, dict_item_key_by_arg: str | int = None, dict_item_key_by_func: bool = None, func_name_striped: bool = None, execute_if_none: bool = None, module_name: str = None, arg0: str = None, module_name_striped: bool = None, search_from_self: bool = None): ...

def _set_dict_item_value_by_setter_with_agr(self:He, func, args, kwargs, dict_attr_name, dict_item_key, dict_item_key_by_arg, func_name_striped, value_agr_sn, value_type, es:HeEro): ...
def set_dict_item_value_by_setter_with_agr(dict_attr_name: str = None, dict_item_key: str = None, dict_item_key_by_arg: str | int = None, func_name_striped: bool = None, value_agr_sn:int=None, value_type:str|list[str]|tuple=None): ...
def set_self_item_value_by_setter_with_agr(dict_item_key: str = None, dict_item_key_by_arg: str | int = None, func_name_striped: bool = None, value_agr_sn:int=None, value_type:str|list[str]|tuple=None): ...
def set_self_x_item_value_by_setter_with_agr(dict_item_key: str = None, dict_item_key_by_arg: str | int = None, func_name_striped: bool = None, value_agr_sn:int=None, value_type:str|list[str]|tuple=None): ...
def set_self_d_item_value_by_setter_with_agr(dict_item_key: str = None, dict_item_key_by_arg: str | int = None, func_name_striped: bool = None, value_agr_sn:int=None, value_type:str|list[str]|tuple=None): ...

def _redirect_to_attribute_function(self:He, func, args, kwargs, func_attr_name, func_name_striped, es:HeEro): ...
def redirect_to_attribute_function(func_attr_name: str = None, func_name_striped: bool = None): ...

def _redirect_to_attribute_property(self:He, func, func_attr_name, func_name_striped, es:HeEro): ...
def redirect_to_attribute_property(func_attr_name: str = None, func_name_striped: bool = None): ...
