from .....configs import Configs
from .. import Webmod


class Settings(Configs):
    def __init__(self, u: Webmod): ...
    @property
    def __u__(self)-> Webmod: ...

    @property
    def page_feature(self)-> str: ...
    @page_feature.setter
    def page_feature(self, value) -> None: ...
    def is_page_feature_general(self)-> bool: ...
    def is_page_feature_sign_in(self)-> bool: ...
    def is_page_feature_sign_out(self)-> bool: ...
    def is_page_feature_sign_reset(self)-> bool: ...
    def is_page_feature_sign_up(self)-> bool: ...
    @property
    def power(self)-> str: ...
    @power.setter
    def power(self, value) -> None: ...
    def is_power_public(self)-> bool: ...
    def is_power_groups(self)-> bool: ...
    def is_power_inherited(self)-> bool: ...
    def is_power_members(self)-> bool: ...

    @property
    def page_layout(self)-> str: ...
    @page_layout.setter
    def page_layout(self, value) -> None: ...

    @property
    def icon(self)-> str: ...
    @icon.setter
    def icon(self, value) -> None: ...
