from .components import Components
from .configs import Configs
from .debugs import Debugs
from .i import I
from .types import Types
from .types.he import He


class System(He):
    def __init__(self): ...
    @property
    def __i__(self)-> I: ...
    @property
    def components(self)-> Components: ...
    @property
    def configs(self)-> Configs: ...
    @property
    def debugs(self)-> Debugs: ...
    @property
    def types(self)-> Types: ...

    def create_website(self): ...
