from .. import Debugs
from ....types.he import He


class Input(He):
    @property
    def __u__(self)-> Debugs: ...
    def input(self, label=None, prefix=None, color=None, bgcolor=None, bright=None)-> str: ...
    def primary(self, label=None, prefix=None)-> str: ...
    def secondary(self, label=None, prefix=None)-> str: ...
    def success(self, label=None, prefix=None)-> str: ...
    def warning(self, label=None, prefix=None)-> str: ...
    def danger(self, label=None, prefix=None)-> str: ...
    def info(self, label=None, prefix=None)-> str: ...
    def comment(self, label=None, prefix=None)-> str: ...

