from ....types.he import He


class Webapp(He):
    def __init__(self, webmod):
        super().__init__(webmod)

    @property
    def x(self): return self.__u__

    def page_iterative(self): pass
    def page_content(self): pass

    def page_layout(self): pass

    def page_block_navbar(self): pass
    def page_block_breadcrumb(self): pass
    def page_block_navigations(self): pass
    def page_block_messages(self): pass
    def page_block_footer(self): pass
    def page_block_debugs(self): pass

    def page_block_1010(self): pass
    def page_block_1020(self): pass
    def page_block_1030(self): pass
    def page_block_1040(self): pass
    def page_block_1050(self): pass
    def page_block_1060(self): pass
    def page_block_1070(self): pass
    def page_block_1080(self): pass
    def page_block_1090(self): pass
    def page_block_1100(self): pass
