from ..file import File
from ...types.hd import Hd
from ...types.he import He


class Configs(Hd):
    def __init__(self, u: He, data: dict = None, end_class: type = None, start_class: type = None, file: str | File = None, defaults:dict=None): ...

    @property
    def ___value_types___(self)-> dict[str, str]: ...

    @property
    def ___hooks___(self)-> dict[str, tuple[Configs, str]]: ...
    def hook(self, name: str, target_configs: Configs, target_name: str = None): ...

    @property
    def ___defaults___(self) -> Configs: ...

    def __getitem__(self, name): ...
    def __setitem__(self, name: str, value): ...
    def get(self, name): ...
    def set(self, name: str, value): ...


    @property
    def ___file___(self)-> File | None: ...

    def save(self): ...
