from .cls import Cls
from .med import Med
from ..file import File
from ...types.he import He


class CssMaker(He):
    def __init__(self, u: He, file: str | File = None): ...

    @property
    def file(self)-> File | None: ...
    @property
    def version(self)-> str: ...

    @property
    def sizes(self)-> list[str]: ...
    @sizes.setter
    def sizes(self, value: list[str]): return

    @property
    def cls_root(self)-> Cls: ...
    @property
    def css_html(self)-> Cls: ...
    @property
    def css_body(self)-> Cls: ...

    @property
    def clses(self)-> dict[str, Cls]: ...
    def cls(self, name:str, media_min_width:int=None, media_max_width:int=None, media_min_height:int=None, media_max_height:int=None)-> Cls: ...

    @property
    def medes(self)-> dict[str, Cls]: ...
    def med(self, media_min_width:int=None, media_max_width:int=None, media_min_height:int=None, media_max_height:int=None)-> Med: ...

    def save(self, minimized: bool = None): ...