class Menu(dict):
    def __init__(self, title=None, url=None): ...
    @property
    def title(self): ...
    @title.setter
    def title(self, value): ...
    @property
    def url(self): ...
    @url.setter
    def url(self, value): ...
