from .. import Debugs
from ....types.he import He


class Output(He):
    @property
    def __u__(self)-> Debugs: ...
    def print(self, content=None, error=None, comment=None, file=None, prefix=None, color=None, bgcolor=None, bright=None, subsystem=None)-> None: ...
    def primary(self, content=None, error=None, comment=None, file=None, prefix=None)-> None: ...
    def secondary(self, content=None, error=None, comment=None, file=None, prefix=None)-> None: ...
    def success(self, content=None, error=None, comment=None, file=None, prefix=None)-> None: ...
    def warning(self, content=None, error=None, comment=None, file=None, prefix=None)-> None: ...
    def danger(self, content=None, error=None, comment=None, file=None, prefix=None)-> None: ...
    def info(self, content=None, error=None, comment=None, file=None, prefix=None)-> None: ...
    def comment(self, content=None, error=None, comment=None, file=None, prefix=None)-> None: ...
