from ..address import Address
from .... import WebSystem
from ......types.hd import Hd
from ....configs import Configs
from ....clients import Clients
from .. import Client
from .headers import Headers
from .arguments import Arguments
from .form import Form


class Request(Hd):
    @property
    def __websystem__(self)-> WebSystem: ...
    @property
    def __clients__(self)-> Clients: ...
    @property
    def __client__(self)-> Client: ...
    @property
    def __configs__(self)-> Configs: ...
    @property
    def address(self)-> Address: ...
    @property
    def headers(self)-> Headers: ...
    @property
    def arguments(self)-> Arguments: ...
    @property
    def form(self)-> Form: ...
    @property
    def method(self)-> str: ...
    def is_method_post(self)-> bool: ...
    def is_method_get(self)-> bool: ...
    @property
    def url(self)-> str: ...
    @property
    def path(self)-> str: ...
    @property
    def remote_addr(self)-> str: ...
