from ..cls_type import ClsType
from ..configs import Configs
from ..folder import Folder
from ...types.he import He
from ...types.hd import Hd
from ..multilinguals.package import Package


class Multilinguals(Hd):
    def __init__(self, u: He, end_class: type = None, start_class: type = None, folder: Folder | str = None, hooked_configs: Configs = None, hooked_config_name: str = None): ...

    @property
    def ___tree_cls_types___(self)-> list[ClsType]: ...

    @property
    def ___hooked_configs___(self)-> Configs | None: ...
    @property
    def ___hooked_config_name___(self)-> str | None: ...

    @property
    def folder(self)-> Folder: ...

    def package(self, language: str)-> Package: ...

    @property
    def default(self)-> Package: ...

    @property
    def runtime(self)-> Package: ...

    def ml(self, code: str, language: str = None, replace: str = None, return_code: bool = None)-> str: ...
    def ml_name(self, language: str = None, replace: str = None, return_code: bool = None)-> str: ...
    def ml_abbreviation(self, language: str = None, replace: str = None, return_code: bool = None)-> str: ...
    def ml_title(self, language: str = None, replace: str = None, return_code: bool = None)-> str: ...
    def ml_description(self, language: str = None, replace: str = None, return_code: bool = None)-> str: ...
    def ml_link_title(self, language: str = None, replace: str = None, return_code: bool = None)-> str: ...
    def ml_page_title(self, language: str = None, replace: str = None, return_code: bool = None)-> str: ...
    def ml_breadcrumb_title(self, language: str = None, replace: str = None, return_code: bool = None)-> str: ...
