from .....types.he import He
from ... import Database
from .. import Tables
from .columns import Columns
from .data import Data
from ...configs import Configs
from ...connection import Connection


class Table(He):
    def __init__(self, u: Tables, name: str): ...
    @property
    def __database__(self)-> Database: ...
    @property
    def __tables__(self)-> Tables: ...
    @property
    def __configs__(self)-> Configs: ...
    @property
    def __connection__(self)-> Connection: ...
    @property
    def name(self)-> str: ...
    @property
    def columns(self)-> Columns: ...
    @property
    def data(self)-> Data: ...
    @property
    def fullname(self)-> str: ...

    def exists(self)-> bool: ...
    def create(self)-> bool: ...
    def delete(self)-> bool: ...
