from .tags.a import A
from .tags.b import B
from .tags.base import Base
from .tags.body import Body
from .tags.button import Button
from .tags.code import Code
from .tags.dd import Dd
from .tags.div import Div
from .tags.dl import Dl
from .tags.dt import Dt
from .tags.form import Form
from .tags.h1 import H1
from .tags.h2 import H2
from .tags.h3 import H3
from .tags.h4 import H4
from .tags.h5 import H5
from .tags.h6 import H6
from .tags.head import Head
from .tags.hr import Hr
from .tags.html import Html
from .tags.i import I
from .tags.img import Img
from .tags.input import Input
from .tags.input_text import InputText
from .tags.li import Li
from .tags.link import Link
from .tags.meta import Meta
from .tags.nav import Nav
from .tags.pre import Pre
from .tags.script import Script
from .tags.span import Span
from .tags.style import Style
from .tags.table import Table
from .tags.tbody import Tbody
from .tags.td import  Td
from .tags.th import  Th
from .tags.thead import Thead
from .tags.title import Title
from .tags.tr import Tr
from .tags.ul import Ul

class TagsCreater:
    # a
    def A(self, title=None, url: str = None, attributes:dict[str, str|int|float|None]=None) -> A: ...
    # b
    def B(self, content=None, attributes:dict[str, str|int|float|None]=None) -> B:...
    # base
    def Base(self, attributes:dict[str, str|int|float|None]=None) -> Base:...
    # body
    def Body(self, content=None, attributes:dict[str, str|int|float|None]=None) -> Body:...
    # button
    def Button(self, title=None, attributes:dict[str, str|int|float|None]=None) -> Button:...
    # code
    def Code(self, content:str=None, attributes:dict[str, str|int|float|None]=None) -> Code:...
    # dd
    def Dd(self, content=None, attributes:dict[str, str|int|float|None]=None) -> Dd:...
    # div
    def Div(self, content=None, attributes:dict[str, str|int|float|None]=None) -> Div:...
    # dl
    def Dl(self, attributes:dict[str, str|int|float|None]=None) -> Dl:...
    # dt
    def Dt(self, content=None, attributes:dict[str, str|int|float|None]=None) -> Dt:...
    # form
    def Form(self, action: str = None, attributes:dict[str, str|int|float|None]=None) -> Form:...
    # h1
    def H1(self, content=None, attributes:dict[str, str|int|float|None]=None) -> H1:...
    # h2
    def H2(self, content=None, attributes:dict[str, str|int|float|None]=None) -> H2:...
    # h3
    def H3(self, content=None, attributes:dict[str, str|int|float|None]=None) -> H3:...
    # h4
    def H4(self, content=None, attributes:dict[str, str|int|float|None]=None) -> H4:...
    # h5
    def H5(self, content=None, attributes:dict[str, str|int|float|None]=None) -> H5:...
    # h6
    def H6(self, content=None, attributes:dict[str, str|int|float|None]=None) -> H6:...
    # head
    def Head(self, attributes:dict[str, str|int|float|None]=None) -> Head:...
    # hr
    def Hr(self, attributes:dict[str, str|int|float|None]=None) -> Hr:...
    # html
    def Html(self, attributes:dict[str, str|int|float|None]=None) -> Html: ...
    # i
    def I(self, content=None, attributes:dict[str, str|int|float|None]=None) -> I:...
    # img
    def Input(self, name: str = None, value: str = None, attributes:dict[str, str|int|float|None]=None) -> Input:...
    # input
    def Img(self, url=None, width=None, height=None, title:str= None, attributes:dict[str, str|int|float|None]=None) -> Img:...
    # input_text
    def InputText(self, name: str = None, value: str = None, placeholder:str=None, attributes:dict[str, str|int|float|None]=None) -> InputText:...
    # li
    def Li(self, content=None, attributes:dict[str, str|int|float|None]=None) -> Li:...
    # link
    def Link(self, url=None, attributes:dict[str, str|int|float|None]=None) -> Link:...
    # meta
    def Meta(self, attributes:dict[str, str|int|float|None]=None) -> Meta:...
    # nav
    def Nav(self, content=None, attributes:dict[str, str|int|float|None]=None) -> Nav:...
    # pre
    def Pre(self, content=None, attributes:dict[str, str|int|float|None]=None) -> Pre:...
    # script
    def Script(self, content:str=None, attributes:dict[str, str|int|float|None]=None) -> Script:...
    # span
    def Span(self, content=None, attributes:dict[str, str|int|float|None]=None) -> Span:...
    # style
    def Style(self, content:str=None, attributes:dict[str, str|int|float|None]=None) -> Style:...
    # table
    def Table(self, attributes:dict[str, str|int|float|None]=None) -> Table:...
    # tbody
    def Tbody(self, attributes:dict[str, str|int|float|None]=None) -> Tbody:...
    # td
    def Td(self, content=None, colspan:int=None, rowspan:int=None, attributes:dict[str, str|int|float|None]=None) -> Td:...
    # th
    def Th(self, content=None, colspan:int=None, rowspan:int=None, attributes:dict[str, str|int|float|None]=None) -> Th:...
    # thead
    def Thead(self, content=None, attributes:dict[str, str|int|float|None]=None) -> Thead:...
    # title
    def Title(self, content=None, attributes:dict[str, str|int|float|None]=None) -> Title:...
    # tr
    def Tr(self, attributes:dict[str, str|int|float|None]=None) -> Tr:...
    # ul
    def Ul(self, attributes:dict[str, str|int|float|None]=None) -> Ul:...
