from ..... import WebSystem
from .......types.hd import Hd
from .....configs import Configs
from .....clients import Clients
from ... import Client
from .. import Request


class Headers(Hd):
    @property
    def __websystem__(self)-> WebSystem: ...
    @property
    def __clients__(self)-> Clients: ...
    @property
    def __client__(self)-> Client: ...
    @property
    def __request__(self)-> Request: ...
    @property
    def __configs__(self)-> Configs: ...

    @property
    def host(self)-> str: ...
    @property
    def connection(self)-> str: ...
    @property
    def cache_control(self)-> str: ...
    @property
    def sec_ch_ua(self)-> str: ...
    @property
    def sec_ch_ua_mobile(self)-> str: ...
    @property
    def sec_ch_ua_platform(self)-> str: ...
    @property
    def upgrade_insecure_requests(self)-> str: ...
    @property
    def user_agent(self)-> str: ...
    @property
    def accept(self)-> str: ...
    @property
    def sec_fetch_site(self)-> str: ...
    @property
    def sec_fetch_mode(self)-> str: ...
    @property
    def sec_fetch_user(self)-> str: ...
    @property
    def sec_fetch_dest(self)-> str: ...
    @property
    def accept_encoding(self)-> str: ...
    @property
    def accept_language(self)-> str: ...
    @property
    def cookie(self)-> str: ...
