from ...configs import Configs as ModConfigs
from ....types.he import He


class Configs(ModConfigs):
    def __init__(self, u: He): ...
    @property
    def language(self)-> str: ...
    @language.setter
    def language(self, value) -> None: ...
    @property
    def output_minimized(self)-> bool: ...
    @output_minimized.setter
    def output_minimized(self, value) -> None: ...
    @property
    def output_unspaced(self)-> bool: ...
    @output_unspaced.setter
    def output_unspaced(self, value) -> None: ...
    @property
    def output_comments(self)-> bool: ...
    @output_comments.setter
    def output_comments(self, value) -> None: ...
    @property
    def output_indentation(self)-> str: ...
    @output_indentation.setter
    def output_indentation(self, value) -> None: ...
    @property
    def title_delimiter(self)-> str: ...
    @title_delimiter.setter
    def title_delimiter(self, value) -> None: ...
    @property
    def title_ascending(self)-> bool: ...
    @title_ascending.setter
    def title_ascending(self, value) -> None: ...
