from ...configs import Configs as ModConfigs
from .. import WebSystem


class Configs(ModConfigs):
    def __init__(self, system: WebSystem): ...
    @property
    def __u__(self)-> WebSystem: ...

    @property
    def language(self)-> str: ...
    @language.setter
    def language(self, value) -> None: ...

    @property
    def session_expiry(self)-> int: ...
    @session_expiry.setter
    def session_expiry(self, value) -> None: ...

    @property
    def host(self)-> str: ...
    @host.setter
    def host(self, value) -> None: ...

    @property
    def port(self)-> int: ...
    @port.setter
    def port(self, value) -> None: ...

    @property
    def mysql_host(self)-> str: ...
    @mysql_host.setter
    def mysql_host(self, value) -> None: ...
    @property
    def mysql_port(self)-> int: ...
    @mysql_port.setter
    def mysql_port(self, value) -> None: ...
    @property
    def mysql_user(self)-> str: ...
    @mysql_user.setter
    def mysql_user(self, value) -> None: ...
    @property
    def mysql_password(self)-> str: ...
    @mysql_password.setter
    def mysql_password(self, value) -> None: ...
    @property
    def mysql_dbname(self)-> str: ...
    @mysql_dbname.setter
    def mysql_dbname(self, value) -> None: ...
    @property
    def mysql_prefix(self)-> str: ...
    @mysql_prefix.setter
    def mysql_prefix(self, value) -> None: ...

    @property
    def mysql_max_connections(self)-> int: ...
    @mysql_max_connections.setter
    def mysql_max_connections(self, value) -> None: ...
    @property
    def mysql_connect_timeout(self)-> int: ...
    @mysql_connect_timeout.setter
    def mysql_connect_timeout(self, value) -> None: ...

    @property
    def mysql_column_key_sn(self)-> str: ...
    @mysql_column_key_sn.setter
    def mysql_column_key_sn(self, value) -> None: ...
    @property
    def mysql_column_key_id(self)-> str: ...
    @mysql_column_key_id.setter
    def mysql_column_key_id(self, value) -> None: ...
    @property
    def mysql_column_key_az(self)-> str: ...
    @mysql_column_key_az.setter
    def mysql_column_key_az(self, value) -> None: ...
    @property
    def mysql_column_key_kw(self)-> str: ...
    @mysql_column_key_kw.setter
    def mysql_column_key_kw(self, value) -> None: ...
    @property
    def mysql_column_key_ur(self)-> str: ...
    @mysql_column_key_ur.setter
    def mysql_column_key_ur(self, value) -> None: ...
    @property
    def mysql_column_key_dc(self)-> str: ...
    @mysql_column_key_dc.setter
    def mysql_column_key_dc(self, value) -> None: ...
    @property
    def mysql_column_key_du(self)-> str: ...
    @mysql_column_key_du.setter
    def mysql_column_key_du(self, value) -> None: ...
    @property
    def mysql_data_admin_id(self)-> str: ...
    @mysql_data_admin_id.setter
    def mysql_data_admin_id(self, value) -> None: ...

    @property
    def module(self)-> str: ...
    @module.setter
    def module(self, value) -> None: ...

    @property
    def webmod_page_content_sign_in(self)-> str: ...
    @webmod_page_content_sign_in.setter
    def webmod_page_content_sign_in(self, value) -> None: ...

    @property
    def webmod_page_content_sign_out(self)-> str: ...
    @webmod_page_content_sign_out.setter
    def webmod_page_content_sign_out(self, value) -> None: ...

    @property
    def webmod_page_content_sign_up(self)-> str: ...
    @webmod_page_content_sign_up.setter
    def webmod_page_content_sign_up(self, value) -> None: ...

    @property
    def webmod_page_content_sign_reset(self)-> str: ...
    @webmod_page_content_sign_reset.setter
    def webmod_page_content_sign_reset(self, value) -> None: ...

    @property
    def webmod_page_content_admin(self)-> str: ...
    @webmod_page_content_admin.setter
    def webmod_page_content_admin(self, value) -> None: ...

    @property
    def webmod_page_content_about(self)-> str: ...
    @webmod_page_content_about.setter
    def webmod_page_content_about(self, value) -> None: ...

    @property
    def webmod_page_content_contact(self)-> str: ...
    @webmod_page_content_contact.setter
    def webmod_page_content_contact(self, value) -> None: ...

    @property
    def webmod_page_layout(self)-> str: ...
    @webmod_page_layout.setter
    def webmod_page_layout(self, value) -> None: ...

    @property
    def webmod_page_block_1010(self)-> str: ...
    @webmod_page_block_1010.setter
    def webmod_page_block_1010(self, value) -> None: ...

    @property
    def webmod_page_block_1020(self)-> str: ...
    @webmod_page_block_1020.setter
    def webmod_page_block_1020(self, value) -> None: ...

    @property
    def webmod_page_block_1030(self)-> str: ...
    @webmod_page_block_1030.setter
    def webmod_page_block_1030(self, value) -> None: ...

    @property
    def webmod_page_block_1040(self)-> str: ...
    @webmod_page_block_1040.setter
    def webmod_page_block_1040(self, value) -> None: ...

    @property
    def webmod_page_block_1050(self)-> str: ...
    @webmod_page_block_1050.setter
    def webmod_page_block_1050(self, value) -> None: ...

    @property
    def webmod_page_block_1060(self)-> str: ...
    @webmod_page_block_1060.setter
    def webmod_page_block_1060(self, value) -> None: ...

    @property
    def webmod_page_block_1070(self)-> str: ...
    @webmod_page_block_1070.setter
    def webmod_page_block_1070(self, value) -> None: ...

    @property
    def webmod_page_block_1080(self)-> str: ...
    @webmod_page_block_1080.setter
    def webmod_page_block_1080(self, value) -> None: ...

    @property
    def webmod_page_block_1090(self)-> str: ...
    @webmod_page_block_1090.setter
    def webmod_page_block_1090(self, value) -> None: ...

    @property
    def webmod_page_block_1100(self)-> str: ...
    @webmod_page_block_1100.setter
    def webmod_page_block_1100(self, value) -> None: ...

    @property
    def webmod_page_block_navbar(self)-> str: ...
    @webmod_page_block_navbar.setter
    def webmod_page_block_navbar(self, value) -> None: ...

    @property
    def webmod_page_block_breadcrumb(self)-> str: ...
    @webmod_page_block_breadcrumb.setter
    def webmod_page_block_breadcrumb(self, value) -> None: ...

    @property
    def webmod_page_block_navigations(self)-> str: ...
    @webmod_page_block_navigations.setter
    def webmod_page_block_navigations(self, value) -> None: ...

    @property
    def webmod_page_block_messages(self)-> str: ...
    @webmod_page_block_messages.setter
    def webmod_page_block_messages(self, value) -> None: ...

    @property
    def webmod_page_block_footer(self)-> str: ...
    @webmod_page_block_footer.setter
    def webmod_page_block_footer(self, value) -> None: ...

    @property
    def webmod_page_block_debugs(self)-> str: ...
    @webmod_page_block_debugs.setter
    def webmod_page_block_debugs(self, value) -> None: ...

    @property
    def html_output_minimized(self)-> str: ...
    @html_output_minimized.setter
    def html_output_minimized(self, value) -> None: ...

    @property
    def html_output_indentation(self)-> str: ...
    @html_output_indentation.setter
    def html_output_indentation(self, value) -> None: ...

    @property
    def html_output_comments(self)-> str: ...
    @html_output_comments.setter
    def html_output_comments(self, value) -> None: ...

    @property
    def html_output_unspaced(self)-> str: ...
    @html_output_unspaced.setter
    def html_output_unspaced(self, value) -> None: ...

    @property
    def html_title_delimiter(self)-> str: ...
    @html_title_delimiter.setter
    def html_title_delimiter(self, value) -> None: ...

    @property
    def html_title_ascending(self)-> bool: ...
    @html_title_ascending.setter
    def html_title_ascending(self, value) -> None: ...

    @property
    def url_root_path(self)-> str: ...
    @url_root_path.setter
    def url_root_path(self, value) -> None: ...

    @property
    def url_key_language(self)-> str: ...
    @url_key_language.setter
    def url_key_language(self, value) -> None: ...

    @property
    def url_key_mode(self)-> str: ...
    @url_key_mode.setter
    def url_key_mode(self, value) -> None: ...

    @property
    def url_key_module(self)-> str: ...
    @url_key_module.setter
    def url_key_module(self, value) -> None: ...

    @property
    def url_key_arguments(self)-> str: ...
    @url_key_arguments.setter
    def url_key_arguments(self, value) -> None: ...

    @property
    def url_key_keyword(self)-> str: ...
    @url_key_keyword.setter
    def url_key_keyword(self, value) -> None: ...

    @property
    def url_key_page(self)-> str: ...
    @url_key_page.setter
    def url_key_page(self, value) -> None: ...

    @property
    def url_key_orders(self)-> str: ...
    @url_key_orders.setter
    def url_key_orders(self, value) -> None: ...

    @property
    def url_key_filters(self)-> str: ...
    @url_key_filters.setter
    def url_key_filters(self, value) -> None: ...

    @property
    def url_key_items_per_page(self)-> str: ...
    @url_key_items_per_page.setter
    def url_key_items_per_page(self, value) -> None: ...

    @property
    def url_key_pages_per_group(self)-> str: ...
    @url_key_pages_per_group.setter
    def url_key_pages_per_group(self, value) -> None: ...

    @property
    def url_key_security(self)-> str: ...
    @url_key_security.setter
    def url_key_security(self, value) -> None: ...

    @property
    def url_key_reference(self)-> str: ...
    @url_key_reference.setter
    def url_key_reference(self, value) -> None: ...

    @property
    def pagination_items_per_page(self)-> int: ...
    @pagination_items_per_page.setter
    def pagination_items_per_page(self, value) -> None: ...

    @property
    def pagination_pages_per_group(self)-> int: ...
    @pagination_pages_per_group.setter
    def pagination_pages_per_group(self, value) -> None: ...


    @property
    def logo(self)-> str: ...
    @logo.setter
    def logo(self, value) -> None: ...
