from ..core import CssMaker
from ....types.he import He


class Cls(He):
    def __init__(self, u, name: str): ...

    @property
    def __u__(self)-> CssMaker: ...

    @property
    def name(self)-> str: ...
    @property
    def atrs(self)-> dict[str, str]: ...

    def atr(self, name:str=None, value:str=None): ...
    def atr_px(self, name:str=None, value:str|int|float=None): ...
