from ...configs import Configs as ModConfigs
from ....types.he import He


class Configs(ModConfigs):
    def __init__(self, u: He): ...
    @property
    def connection(self)-> str: ...
    @connection.setter
    def connection(self, value) -> None: ...
    @property
    def host(self)-> str: ...
    @host.setter
    def host(self, value) -> None: ...
    @property
    def port(self)-> int: ...
    @port.setter
    def port(self, value) -> None: ...
    @property
    def user(self)-> str: ...
    @user.setter
    def user(self, value) -> None: ...
    @property
    def password(self)-> str: ...
    @password.setter
    def password(self, value) -> None: ...
    @property
    def dbname(self)-> str: ...
    @dbname.setter
    def dbname(self, value) -> None: ...
    @property
    def prefix(self)-> str: ...
    @prefix.setter
    def prefix(self, value) -> None: ...
    @property
    def max_connections(self)-> int: ...
    @max_connections.setter
    def max_connections(self, value) -> None: ...
    @property
    def connect_timeout(self)-> int: ...
    @connect_timeout.setter
    def connect_timeout(self, value) -> None: ...
    @property
    def column_key_sn(self)-> str: ...
    @column_key_sn.setter
    def column_key_sn(self, value) -> None: ...
    @property
    def column_key_id(self)-> str: ...
    @column_key_id.setter
    def column_key_id(self, value) -> None: ...
    @property
    def column_key_az(self)-> str: ...
    @column_key_az.setter
    def column_key_az(self, value) -> None: ...
    @property
    def column_key_kw(self)-> str: ...
    @column_key_kw.setter
    def column_key_kw(self, value) -> None: ...
    @property
    def column_key_ur(self)-> str: ...
    @column_key_ur.setter
    def column_key_ur(self, value) -> None: ...
    @property
    def column_key_dc(self)-> str: ...
    @column_key_dc.setter
    def column_key_dc(self, value) -> None: ...
    @property
    def column_key_du(self)-> str: ...
    @column_key_du.setter
    def column_key_du(self, value) -> None: ...
    @property
    def data_admin_id(self)-> str: ...
    @data_admin_id.setter
    def data_admin_id(self, value) -> None: ...
