from ......types.hd import Hd
from .. import Htmdoc
from .....htmdoc.nodes.wrap import Wrap


class Areas(Hd):
    @property
    def __document__(self)-> Htmdoc: ...

    def add(self, name: str, area: Wrap): ...

    def get(self, name: str)-> Wrap | None: ...

    @property
    def content(self)-> Wrap: ...
    @content.setter
    def content(self, area: Wrap): ...

    @property
    def navbar(self)-> Wrap: ...
    @navbar.setter
    def navbar(self, area: Wrap): ...

    @property
    def breadcrumb(self)-> Wrap: ...
    @breadcrumb.setter
    def breadcrumb(self, area: Wrap): ...

    @property
    def navigations(self)-> Wrap: ...
    @navigations.setter
    def navigations(self, area: Wrap): ...

    @property
    def footer(self)-> Wrap: ...
    @footer.setter
    def footer(self, area: Wrap): ...

    @property
    def messages(self)-> Wrap: ...
    @messages.setter
    def messages(self, area: Wrap): ...

    @property
    def debugs(self)-> Wrap: ...
    @debugs.setter
    def debugs(self, area: Wrap): ...
