from ...configs import Configs as PluCfg
from ...file import File
from ...folder import Folder
from ...mod_type import ModType


class Configs(PluCfg):
    @property
    def mainpy(self)-> str: ...
    @mainpy.setter
    def mainpy(self, value: str): ...

    @property
    def website_module(self)-> str: ...
    @website_module.setter
    def website_module(self, value: str): ...

    @property
    def exe_name(self)-> str: ...
    @exe_name.setter
    def exe_name(self, value: str): ...

    @property
    def show_console(self)-> bool: ...
    @show_console.setter
    def show_console(self, value: bool): ...

    @property
    def one_file(self)-> bool: ...
    @one_file.setter
    def one_file(self, value: bool): ...

    @property
    def one_dir(self)-> bool: ...
    @one_dir.setter
    def one_dir(self, value: bool): ...

    @property
    def pack_overwrite(self)-> bool: ...
    @pack_overwrite.setter
    def pack_overwrite(self, value: bool): ...

    @property
    def root_folders(self)-> list[Folder]: ...
    @root_folders.setter
    def root_folders(self, value: list[Folder]): ...

    @property
    def root_modules(self)-> list[ModType]: ...
    @root_modules.setter
    def root_modules(self, value: list[ModType]): ...

    @property
    def dist_path(self)-> Folder: ...
    @dist_path.setter
    def dist_path(self, value: Folder): ...

    @property
    def build_path(self)-> Folder: ...
    @build_path.setter
    def build_path(self, value: Folder): ...

    @property
    def spec_path(self)-> Folder: ...
    @spec_path.setter
    def spec_path(self, value: Folder): ...

    @property
    def comd_path(self)-> Folder: ...
    @comd_path.setter
    def comd_path(self, value: Folder): ...

    @property
    def icon_file(self)-> File: ...
    @icon_file.setter
    def icon_file(self, value: File): ...

    @property
    def version_file(self)-> File: ...
    @version_file.setter
    def version_file(self, value: File): ...
