from ...functions.decorators import instance_he_by_module_name
from ..types.he import He


class Types(He):
    _a0 = {'arg0':'__s__'}

    @instance_he_by_module_name(**_a0)
    def hd(self, data: dict=None): return
    @instance_he_by_module_name(**_a0)
    def he(self, data: dict=None): return
    @instance_he_by_module_name(**_a0)
    def hf(self, number: str | float | int): return
    @instance_he_by_module_name(**_a0)
    def hi(self, number: str | float | int): return
    @instance_he_by_module_name(**_a0)
    def hl(self, data: list=None): return
    @instance_he_by_module_name(**_a0)
    def hm(self, data: list=None): return
    @instance_he_by_module_name(**_a0)
    def hs(self, string: str): return


