from .hd import Hd
from .he import He
from .hf import Hf
from .hi import Hi
from .hl import Hl
from .hs import Hs


class Types(He):
    def hd(self, data: dict=None)-> Hd: ...
    def he(self, data: dict=None)-> He: ...
    def hf(self, number: str | float | int)-> Hf: ...
    def hm(self, number: str | float | int)-> Hm: ...
    def hi(self, number: str | float | int)-> Hi: ...
    def hl(self, data: list=None)-> Hl: ...
    def hs(self, string: str)-> Hs: ...
