class Limits(dict):
    def __init__(self, start: int = None, quantity: int = None): ...

    def set(self, start: int, quantity: int)-> None: ...

    @property
    def start(self)-> int: ...
    @start.setter
    def start(self, value: int) -> None: ...

    @property
    def quantity(self)-> int: ...
    @quantity.setter
    def quantity(self, value: int) -> None: ...

    def output(self) -> str: ...
