from .configs import Configs
from ..file import File
from ..folder import Folder
from ..mod_type import ModType
from ...types.he import He


class ExePacker(He):
    def __init__(self, u: He, mainpy:str, website_module:str=None, one_file:bool=False, one_dir:bool=False, show_console:bool=False, pack_overwrite:bool=False): ...

    @property
    def configs(self)-> Configs: ...
    def add_root_folder(self, folder: str | Folder): ...
    def ___check_root_module___(self, module: str | ModType)-> ModType | None: ...
    def add_root_module(self, module: str | ModType): ...

    def __output_commands__(self)-> list[str]: ...
    def pack(self): ...
    def output_command(self) -> str: ...
    def save_command(self, file: str|File=None)-> None: ...
