from .i import I
from ... import System
from ...components import Components as SystemComponents
from ...configs import Configs as SystemConfigs
from ...debugs import Debugs as SystemDebugs
from ...types import Types as SystemTypes


class He:
    def __init__(self, u: He):
        self.__x: dict = ...

    @property
    def __i__(self)-> I: ...
    @property
    def __id__(self)-> int: ...
    @property
    def __x__(self)-> dict: ...

    @property
    def __s__(self)-> System: ...
    @property
    def __sm__(self)-> SystemComponents: ...
    @property
    def __sc__(self)-> SystemConfigs: ...
    @property
    def __sd__(self)-> SystemDebugs: ...
    @property
    def __st__(self)-> SystemTypes: ...

    @property
    def __u__(self)-> He | None: ...

    @property
    def __l__(self)-> list: ...

    @property
    def __d__(self)-> dict: ...
