class Condition(dict):
    def __init__(self, column:str, value: str | int | float, judge: str=None, logic:str=None, startwith:bool=None, endwith:bool=None):
        ...
    @property
    def column(self) -> str: ...
    @column.setter
    def column(self, value: str) -> None: ...
    @property
    def value(self) -> str | int | float: ...
    @judge.setter
    def value(self, _value: str | int | float) -> None: ...
    @property
    def judge(self): ...
    @judge.setter
    def judge(self, value: str) -> None: ...
    def set_judge_equal(self) -> None: ...
    def set_judge_un_equal(self) -> None: ...
    def set_judge_less_than(self) -> None: ...
    def set_judge_more_than(self) -> None: ...
    def set_judge_un_less_than(self) -> None: ...
    def set_judge_un_more_than(self) -> None: ...
    def set_judge_like(self) -> None: ...
    def set_judge_regexp(self) -> None: ...
    def set_judge_in_null(self) -> None: ...
    def set_judge_is_not_null(self) -> None: ...
    def set_judge_in(self) -> None: ...
    def set_judge_not_in(self) -> None: ...
    def set_judge_between_and(self) -> None: ...
    def set_judge_spatial(self) -> None: ...
    def set_judge_sounds_like(self) -> None: ...
    @property
    def logic(self) -> str: ...
    def set_logic(self, logic: str) -> None: ...
    def set_logic_and(self) -> None: ...
    def set_logic_or(self) -> None: ...
    @property
    def startwith(self) -> bool: ...
    @startwith.setter
    def startwith(self, value:bool=True) -> None: ...
    def set_startwith(self) -> None: ...
    @property
    def endwith(self) -> bool: ...
    @endwith.setter
    def endwith(self, value:bool=True) -> None: ...
    def set_endwith(self) -> None: ...

    def output(self, logic_requied:bool=False) -> str: ...
