class Orders(dict):
    def __init__(self, orders=None): ...

    def add(self, column: str, by: bool | str = None) -> None: ...

    def adds(self, data: dict = None) -> None: ...

    def output(self) -> str: ...
