from .. import System
from ..components.configs import Configs as ModConfigs


class Configs(ModConfigs):
    def __init__(self, s: System): ...

    @property
    def language(self)-> str: ...
    @language.setter
    def language(self, value) -> None: ...

    @property
    def debug_prefix(self)-> str: ...
    @debug_prefix.setter
    def debug_prefix(self, value) -> None: ...
    @property
    def debug_printable(self)-> bool: ...
    @debug_printable.setter
    def debug_printable(self, value) -> None: ...
    @property
    def debug_saveable(self)-> bool: ...
    @debug_saveable.setter
    def debug_saveable(self, value) -> None: ...
