from .address import Address
from ... import WebSystem
from .....types.hd import Hd
from ...configs import Configs
from ...clients import Clients
from .request import Request


class Client(Hd):
    @property
    def __websystem__(self)-> WebSystem: ...
    @property
    def __clients__(self)-> Clients: ...
    @property
    def __configs__(self)-> Configs: ...

    @property
    def uid(self)-> str: ...
    @property
    def expiry(self)-> int: ...
    @property
    def request(self)-> Request: ...
    def hook_session(self, session)-> None: ...
    @property
    def session(self)-> dict: ...

    def address(self, mode: str = None, module: str = None, arguments: dict[str,str] = None, keyword: str = None, page: int = None, orders: dict[str,str] = None, filters: dict[str,str] = None, items_per_page: int = None, pages_per_group: int = None, reference: str = None, language: str = None, security: str = None)-> Address: ...
    def url(self, mode: str = None, module: str = None, arguments: dict[str,str] = None, keyword: str = None, page: int = None, orders: dict[str,str] = None, filters: dict[str,str] = None, items_per_page: int = None, pages_per_group: int = None, reference: str = None, language: str = None, security: str = None)-> str: ...
    def redirect(self, mode: str = None, module: str = None, arguments: dict[str,str] = None, keyword: str = None, page: int = None, orders: dict[str,str] = None, filters: dict[str,str] = None, items_per_page: int = None, pages_per_group: int = None, reference: str = None, language: str = None, security: str = None): ...
