from .database.core import Database
from ..folder import Folder
from ..mod_path import ModPath
from ..mod_type import ModType
from ...types.he import He
from .configs import Configs
from .server import Server
from .clients import Clients


class WebSystem(He):
    def __init__(self, senior: He, module: str, host: str = None, port: int = None, db_host: str=None, db_user: str=None, db_password: str=None, db_dbname: str=None, db_port: int=None, db_prefix: str=None, configs:dict=None): ...
    @property
    def __debugs_prefix__(self)-> list[str]: ...
    @property
    def configs(self)-> Configs: ...
    @property
    def database(self)-> Database: ...
    @property
    def server(self)-> Server: ...
    @property
    def clients(self)-> Clients: ...
    @property
    def website_mod_path(self)-> ModPath | None: ...
    @property
    def website_mod_type(self)-> ModType | None: ...
    def is_website_exists(self)-> bool: ...
    @property
    def website_folder(self)-> Folder | None: ...
