from ...types.he import He
from ...types.hs import Hs
from ..file import File
from ..folder import Folder


class FileFolder(Hs):
    def __init__(self, u: He, path: str): ...
    @property
    def name(self)-> str: ...

    @property
    def parent(self) -> Folder: ...
    def brother_file(self, name: str) -> File: ...
    def brother_folder(self, name: str) -> Folder: ...
