from ... import Htmdoc
from ..wrap import Wrap


class Tag(Wrap):
    def __init__(self, u: Htmdoc | Wrap, name: str=None, content=None, attributes:dict[str, str|int|float|None]=None) -> None: ...

    @property
    def name(self)-> str: ...
    @property
    def attributes(self)-> dict[str, str|int|float|None]: ...

    def inner_before(self, sn:int)-> Wrap: ...
    @property
    def inner_before1(self)-> Wrap: ...
    @property
    def inner_before2(self)-> Wrap: ...
    @property
    def inner_before3(self)-> Wrap: ...
    @property
    def inner_before4(self)-> Wrap: ...
    @property
    def inner_before5(self)-> Wrap: ...
    def inner_after(self, sn:int)-> Wrap: ...
    @property
    def inner_after1(self)-> Wrap: ...
    @property
    def inner_after2(self)-> Wrap: ...
    @property
    def inner_after3(self)-> Wrap: ...
    @property
    def inner_after4(self)-> Wrap: ...
    @property
    def inner_after5(self)-> Wrap: ...

    @property
    def output_pairable(self)-> bool: ...
    @property
    def output_brealable(self)-> bool: ...
