from ..clients.client.address import Address
from ....types.hd import Hd
from .. import WebSystem
from ..clients.client import Client
from .webmod import Webmod
from .htmdoc import Htmdoc


class Website(Hd):
    def __init__(self, websystem: WebSystem, client: Client): ...

    @property
    def websystem(self) -> WebSystem: ...
    @property
    def client(self) -> Client: ...
    @property
    def htmdoc(self) -> Htmdoc: ...
    @property
    def favicon_ico_url_path(self)-> str: ...
    def webmod(self, *names: str)-> Webmod: ...
    @property
    def webroot(self)-> Webmod: ...

    def address(self, mode: str = None, module: str = None, arguments: dict[str,str] = None, keyword: str = None, page: int = None, orders: dict[str,str] = None, filters: dict[str,str] = None, items_per_page: int = None, pages_per_group: int = None, reference: str = None, language: str = None, security: str = None)-> Address: ...
    def url(self, mode: str = None, module: str = None, arguments: dict[str,str] = None, keyword: str = None, page: int = None, orders: dict[str,str] = None, filters: dict[str,str] = None, items_per_page: int = None, pages_per_group: int = None, reference: str = None, language: str = None, security: str = None)-> str: ...
    def redirect(self, mode: str = None, module: str = None, arguments: dict[str,str] = None, keyword: str = None, page: int = None, orders: dict[str,str] = None, filters: dict[str,str] = None, items_per_page: int = None, pages_per_group: int = None, reference: str = None, language: str = None, security: str = None): ...

    def response(self): ...

