from ...configs import Configs as PluCfg


class Configs(PluCfg):
    @property
    def prefix(self)-> str: ...
    @prefix.setter
    def prefix(self, value: str): ...
    @property
    def printable(self)-> bool: ...
    @printable.setter
    def printable(self, value: str): ...
    @property
    def saveable(self)-> bool: ...
    @saveable.setter
    def saveable(self, value: str): ...