from ....types.hd import Hd
from ...multilinguals import Multilinguals
from ...file import File


class Package(Hd):
    def __init__(self, multilingual: Multilinguals, language: str): ...

    @property
    def __u__(self)-> Multilinguals: ...
    @property
    def language(self)-> str: ...
    @property
    def file(self)-> File: ...

    def read(self, code: str)-> str | None: ...
    def ml(self, code: str, replace: str = None, return_code: bool = False)-> str: ...

    def save(self, code: str | dict[str, str], traslation: str = None)-> None: ...
