from ...types.he import He
from .configs import Configs
from .input import Input
from .output import Output

class Debugs(He):
    @property
    def configs(self)-> Configs: ...
    @property
    def input(self)-> Input: ...
    @property
    def output(self)-> Output: ...
    @property
    def ___prefixes___(self)-> list[str]: ...
    @property
    def prefixes(self)-> list[str]: ...
    def add_prefix(self, prefix: str): ...
    def make_prefix(self, prefix: str | list[str]): ...
