from typing import Any
from .. import Client
from ....configs import Configs as WebSystemConfigs
from .....configs import Configs


class Address(Configs):
    def __init__(self, client: Client, mode: str = None, module: str = None, arguments: dict[str,str] = None, keyword: str = None, page: int = None, orders: dict[str,str] = None, filters: dict[str,str] = None, items_per_page: int = None, pages_per_group: int = None, reference: str = None, language: str = None, security: str = None): ...

    @property
    def __client__(self)-> Client: ...
    @property
    def ___websystem_configs___(self)-> WebSystemConfigs: ...

    @property
    def language(self) -> str:...
    @language.setter
    def language(self, language: str) -> None: ...
    def set_language(self, language: str=None): ...
    def is_language_chinese(self) -> bool: ...
    def is_language_english(self) -> bool: ...
    def set_language_chinese(self) -> None: ...
    def set_language_english(self) -> None: ...

    @property
    def mode(self) -> str:...
    @mode.setter
    def mode(self, mode: str) -> None: ...
    def is_mode_page(self) -> bool: ...
    def is_mode_json(self) -> bool: ...
    def is_mode_ajax(self) -> bool: ...
    def is_mode_grid(self) -> bool: ...
    def is_mode_file(self) -> bool: ...
    def is_mode_not_page(self) -> bool: ...
    def is_mode_not_json(self) -> bool: ...
    def is_mode_not_ajax(self) -> bool: ...
    def is_mode_not_grid(self) -> bool: ...
    def is_mode_not_file(self) -> bool: ...

    @property
    def module(self) -> str:...
    @module.setter
    def module(self, value: str) -> None: ...

    @property
    def security(self) -> str:...
    @security.setter
    def security(self, value: str) -> None: ...

    @property
    def arguments(self) -> dict:...
    @arguments.setter
    def arguments(self, value: dict) -> None: ...

    @property
    def keyword(self) -> str:...
    @keyword.setter
    def keyword(self, value: str) -> None: ...

    @property
    def page(self) -> int:...
    @page.setter
    def page(self, value: int) -> None: ...

    @property
    def orders(self) -> dict[str,str]:...
    @orders.setter
    def orders(self, value: dict[str,str]) -> None: ...

    @property
    def filters(self) -> dict[str,str]:...
    @filters.setter
    def filters(self, value: dict[str,str]) -> None: ...

    @property
    def items_per_page(self) -> int:...
    @items_per_page.setter
    def items_per_page(self, value: int) -> None: ...

    @property
    def pages_per_group(self) -> int:...
    @pages_per_group.setter
    def pages_per_group(self, value: int) -> None: ...

    @property
    def reference(self) -> str:...
    @reference.setter
    def reference(self, value: str) -> None: ...
    def update(self, m: dict, /, **kwargs): ...
    def copy(self)-> Address: ...
    def output(self)-> str: ...
    def data(self)-> dict[str, Any]: ...
    def redirect(self): ...
