from ....types.he import He
from .. import WebSystem
from ..configs import Configs


class Server(He):
    def __init__(self, system: WebSystem): ...

    @property
    def __websystem__(self)-> WebSystem: ...
    @property
    def __configs__(self)-> Configs: ...
    def __deubg_warning__(self, content=None, error=None, comment=None, file=None)-> None: ...
    def __deubg_info__(self, content=None, error=None, comment=None, file=None)-> None: ...

    def make_response_text_html(self, code: str): ...
    def make_response_text_plain(self, text: str): ...
    def make_response_text_css(self, code: str): ...
    def make_response_text_csv(self, code: str): ...
    def make_response_text_markdown(self, code: str): ...
    def make_response_text_xml(self, code: str): ...

    def make_response_error(self, title: str = None, heading: str = None, content: str = None): ...
    def make_response_redirect(self, url): ...
    def make_response_file(self, file, as_attachment=False, mimetype=None, download_name=None): ...
    def make_response_404(self): ...
    @property
    def root_url(self)-> str: ...
    def generate_url(self, *names)-> str: ...
    def run(self): ...
